@@ -1,6 +1,7 @@
 use anyhow::anyhow;
 use std::fmt::{Debug, Formatter, Display};
 use docchi_core::CoreError;
+use std::error::Error;
 
 pub type IntfResult<T> = std::result::Result<T, IntfError>;
 
@@ -10,7 +11,7 @@ pub struct IntfError {
 }
 
 impl IntfError {
-    pub fn new(e : impl Into<anyhow::Error>) -> Self{ Self{ e : e.into() } }
+    pub fn new(e : impl Error + Send + Sync + 'static) -> Self{ Self{ e : e.into() } }
     pub fn to_string(&self) -> String{ self.e.to_string() }
 }
 
@@ -26,6 +27,12 @@ impl Display for IntfError {
     }
 }
 
+impl Error for IntfError{
+    fn source(&self) -> Option<&(dyn Error + 'static)> {
+        self.e.source()
+    }
+}
+
 impl From<CoreError> for IntfError{
     fn from(e : CoreError) -> Self { IntfError::new(e) }
 }
@@ -46,10 +53,4 @@ impl From<&str> for IntfError {
     fn from(s : &str) -> Self {
         Self{ e : anyhow!("{}", s) }
     }
-}
-
-impl Into<anyhow::Error> for IntfError {
-    fn into(self) -> anyhow::Error {
-        self.e
-    }
 }
\ No newline at end of file
